<template>
    <div class="reform-pilot-containter" v-loading="loading" :element-loading-background="loadingColor">
        <div id="trend-chart"></div>
    </div>
</template>

<script>
import * as echarts from 'echarts'
import apiList from '@/api/bigScreen/majorView.js'
export default {
    name: 'projectTrendChart',
    data() {
        return {
            loadingColor: 'rgba(6, 46, 106, 1)',
            loading: false,
            trendChart: null,
            trendChartOption: null,
            legendData: [],
            xAxisData: [],
            seriesData: [],
            valueData: [],
            rateData: null,
        }
    },
    beforeDestroy() {
        this.$bus.$off('changeDate')
    },
    mounted() {
        this.projectName = this.$route.query.title
        this.$emit('searchDateChange')
        this.initTrendChart()
        this.loadData()
        this.$bus.$on('changeDate', () => {
            this.loadData()
        })
    },
    methods: {
        initTrendChart() {
            let chartDom = document.getElementById('trend-chart')
            this.trendChart = echarts.init(chartDom)
            this.trendChartOption = {
                title: {
                    text:this.projectName+ '年度核心指标完成情况趋势图',
                    left: 'center',
                    bottom: '1%',
                    textStyle: {
                        color: '#ffffff',
                        fontSize: 18,
                        fontFamily: 'Microsoft YaHei, Microsoft YaHei'
                    }
                },
                tooltip: {
                    trigger: 'axis',
                    backgroundColor: 'rgba(6, 47, 107, 1)',
                    borderColor: 'rgba(2, 115, 233, 1)',
                    textStyle: {
                        color: '#fff',
                        fontSize: 18,
                    },
                    formatter: (arg) => {
                        let str = '截止' + arg[0].axisValue + '</br>'
                        arg.forEach(item => {
                            let index = item.dataIndex
                            let value = 0
                            if (this.valueData[item.seriesName][index].actualIndexCompleteRate) {
                                value = this.valueData[item.seriesName][index].actualIndexCompleteRate
                            }

                            str = str +
                                '<span style="display:inline-block;font-size:18px;margin-top:5px;">' +
                                item.seriesName +
                                '</span>&nbsp;&nbsp;&nbsp;' + value
                                + '%</br>'
                        })
                        return str
                    },
                },
                legend: {
                    top: '0',
                    left: 'center',
                    type: 'plain',
                    icon: 'rect',
                    inactiveColor: '#333333',
                    itemWidth: 20,
                    itemHeight: 6,
                    textStyle: {
                        color: '#B1E3FF',
                        fontSize: 18,
                    },
                    data: this.legendData,
                },
                grid: {
                    left: '1%',
                    right: '2%',
                    bottom: '8%',
                    containLabel: true,
                },

                xAxis: {
                    type: 'category',
                    type: 'category',
                    boundaryGap: ['0%', '0%'],
                    axisLine: {
                        lineStyle: {
                            color: 'rgba(154,199,220, 0.2)',
                        },
                    },
                    axisLabel: {
                        color: '#D7F1FF',
                        align: 'center',
                        fontSize: 16,
                        padding: [0, 0, 0, 10],
                    },
                    boundaryGap: false,
                    data: ['1月', '2月', '3月', '4月', '5月', '6月', '7月', '8月', '9月', '10月', '11月', '12月'],
                    splitLine: {
                        show: false,
                    },
                },
                yAxis: {
                    min: 0,  //取0为最小刻度
                    max: 100,
                    type: 'value',
                    axisLabel: {
                        color: '#D7F1FF',
                        interval: 0,
                        // showMinLabel: true,
                        // showMaxLabel: true,
                        fontSize: 16,
                    },
                    axisLine: {
                        lineStyle: {
                            color: 'rgba(154,199,220, 0.2)',
                        },
                    },
                    splitLine: {
                        lineStyle: {
                            color: 'rgba(154,199,220, 0.2)',
                        },
                    },
                },
                series: this.seriesData
            }
            this.trendChartOption &&
                this.trendChart.setOption(this.trendChartOption)
            window.addEventListener('resize', () => this.trendChart.resize())
        },
        loadData() {
            this.loading = true
            let data = JSON.parse(sessionStorage.getItem('searchDate'))
            data.projectId = this.$route.query.id
            apiList.getProjectLineChartData(data, (res) => {
                this.valueData = res.data
                this.legendData = Object.keys(res.data)
                this.legendData.forEach((legend, index) => {
                    this.seriesData[index] = {
                        name: legend,
                        type: 'line',
                        data: res.data[legend].map(item => item.indexCompleteRate),
                    }
                })
                this.initTrendChart()
                this.loading = false
            })
        },
    },
}
</script>

<style lang="scss" scoped>
@import '@/assets/css/big-screen.scss';

.reform-pilot-containter {
    width: 100%;
    height: 100%;
    box-sizing: border-box;
    padding-top: 10px;

    #trend-chart {
        width: 100%;
        height: 100%;
    }
}
</style>